//----------------------------------------------------------
// Copyright (C) K-Group srl. All rights reserved.
//----------------------------------------------------------
// KCollection.js

// CTOR
function KCollection(Source, itemConstructor) {
   this.Items = [];
   
   if (typeof Source != 'undefined') {
      this.fromJSON(Source, itemConstructor);
   }
}

KCollection.prototype.defaultItemConstructor = function(Source) {
   return new KObject(Source);
}

// #######################################################
// #                                                     #
// #                    SERIALIZZAZIONE                  #
// #                                                     #

// PARSE JSON
KCollection.prototype.fromJSON = function(Source, itemConstructor) {
   if (typeof itemConstructor == 'undefined') {
      // SE NON E' STATO IMPOSTATO L'ITEM CONSTRUCTOR --> USO QUELLO DI DEFAULT
      itemConstructor = this.defaultItemConstructor;
   }
   
   for (var i = 0; i < Source.length; i++) {
      this.Items[this.Items.length] = itemConstructor(Source[i]);
   }
}

// TO JSON
KCollection.prototype.toJSON = function(propertyFilter) {
   var tmp1 = [];
   
   for (var i = 0; i < this.Items.length; i++) {
      if (typeof this.Items[i].toJSON != 'undefined') {
         // PER L'ELEMENTO CORRENTE E' DEFINITA LA FUNZIONE "toJSON" --> LA USO...
         tmp1[i] = this.Items[i].toJSON(propertyFilter);
      } else {
         // ... ALTRIMENTI USO LA "toString" CLASSICA
         tmp1[i] = this.Items[i].toString();
      }
   }
   
   return '[' + tmp1.join(',') + ']';
}

KCollection.prototype.toString = function(separator) {
   var tmp1 = [];
   // CHECK SU DICHIARAZIONE SEPARATORE CON FALLBACK SU SEPARATORE DI DEFAULT
   if (typeof separator == 'undefined') {
      separator = ',';
   }
   
   for (var i = 0; i < this.Items.length; i++) {
      tmp1[i] = this.Items[i].toString();
   }
   
   return tmp1.join(separator);
}

// #                                                     #
// #                    SERIALIZZAZIONE                  #
// #                                                     #
// #######################################################


// #######################################################
// #                                                     #
// #                     PAGINAZIONE                     #
// #                                                     #

KCollection.prototype.getPageByPos = function(startIndex, maximumItems) {
   var res1 = [];
   
   if (startIndex >= this.Items.length) {
      // L'INDICE DI INIZIO E' SUPERIORE ALLA LUNGHEZZA DELL'ARRAY --> RESITUISCO L'ARRAY VUOTO
      return res1;
   }
   
   // CALCOLO L'INDICE MASSIMO A CUI E' POSSIBILE ARRIVARE
   var endIndex = Math.min(startIndex + maximumItems - 1, this.Items.length - 1);
   
   for (var i = startIndex; i <= endIndex; i++) {
      //alert(this.Items[i].constructor);
      res1[res1.length] = this.Items[i];
   }
   
   return res1;
}

KCollection.prototype.getPage = function(pageIndex, pageSize) {
   return this.getPageByPos(pageIndex * pageSize, pageSize);
}

KCollection.prototype.getPagesCount = function(pageSize) {
   return (Math.floor(this.Items.length / pageSize) + (this.Items.length % pageSize == 0 ? 0 : 1));
}

KCollection.prototype.getNextPageIndex = function(pageIndex, pageSize) {
   return ( ((pageIndex + 1) * pageSize >= this.Items.length) ? 0 : pageIndex + 1 );
}

KCollection.prototype.getPrevPageIndex = function(pageIndex, pageSize) {
   return (pageIndex > 0 ? pageIndex - 1 : this.getPagesCount(pageSize) - 1 );
}

// #                                                     #
// #                     PAGINAZIONE                     #
// #                                                     #
// #######################################################