//----------------------------------------------------------
// Copyright (C) K-Group srl. All rights reserved.
//----------------------------------------------------------
// KCollectionPager.js

// CTOR
function KCollectionPager(Source) {
   this.ItemsCollection = new KCollection();
   this.PageIndex = 0;
   this.PageSize = 2;
   this.PageChangedCallback = null;
   this.SlideshowInterval = 1000;
   
   this.TimerId = null;
   
   KObject.call(this, Source);
}

KCollectionPager.prototype = new KObject();

// #######################################################
// #                                                     #
// #                     PAGINAZIONE                     #
// #                                                     #

KCollectionPager.prototype.getPageByPos = function(startIndex, maximumItems) {
   return this.ItemsCollection.getPageByPos(startIndex, maximumItems);
}

KCollectionPager.prototype.getPage = function(pageIndex, pageSize) {
   if (typeof pageIndex == 'undefined') {
      pageIndex = this.PageIndex;
      pageSize = this.PageSize;
   }
   return this.ItemsCollection.getPage(pageIndex, pageSize);
}

KCollectionPager.prototype.getPagesCount = function(pageSize) {
   if (typeof pageSize == 'undefined') {
      pageSize = this.PageSize;
   }
   return this.ItemsCollection.getPagesCount(pageSize);
}

KCollectionPager.prototype.getNextPageIndex = function(pageIndex, pageSize) {
   if (typeof pageIndex == 'undefined') {
      pageIndex = this.PageIndex;
      pageSize = this.PageSize;
   }
   return this.ItemsCollection.getNextPageIndex(pageIndex, pageSize);
}

KCollectionPager.prototype.getPrevPageIndex = function(pageIndex, pageSize) {
   if (typeof pageIndex == 'undefined') {
      pageIndex = this.PageIndex;
      pageSize = this.PageSize;
   }
   return this.ItemsCollection.getPrevPageIndex(pageIndex, pageSize);
}

// #                                                     #
// #                     PAGINAZIONE                     #
// #                                                     #
// #######################################################

// #######################################################
// #                                                     #
// #                     NAVIGAZIONE                     #
// #                                                     #

KCollectionPager.prototype.goToPage = function(newPageIndex) {
   if (typeof newPageIndex == 'undefined') {
      // SE NON E' DICHIARATO IL PAGE INDEX, USO QUELLO CORRENTE
      newPageIndex = this.PageIndex;
   } else {
      // ALTRIMENTI AGGIORNO IL PAGE INDEX CORRENTE
      this.PageIndex = newPageIndex;
   }
   
   // LANCIA CALLBACK (SE DEFINITA)
   if ( (typeof this.PageChangedCallback != 'undefined') && (this.PageChangedCallback != null) ) {
      this.PageChangedCallback(this);
   }
}

KCollectionPager.prototype.goToNextPage = function() {
   this.goToPage(this.getNextPageIndex());
}

KCollectionPager.prototype.goToPrevPage = function() {
   this.goToPage(this.getPrevPageIndex());
}

KCollectionPager.prototype.stopSlideshow = function() {
   if (this.TimerId != null) {
      window.clearInterval(this.TimerId);
      this.TimerId = null;
   }
}

KCollectionPager.prototype.startForwardSlideshow = function(instanceName) {
   if (typeof instanceName != 'undefined') {
      // BLOCCO LO SLIDESHOW CORRENTE (SE IN ESECUZIONE, PER SICUREZZA)
      this.stopSlideshow();
      
      // FACCIO PARTIRE LO SLIDESHOW NUOVO
      this.TimerId = window.setInterval(instanceName + ".goToNextPage();", this.SlideshowInterval);
   }
}

KCollectionPager.prototype.startBackwardSlideshow = function(instanceName) {
   if (typeof instanceName != 'undefined') {
      // BLOCCO LO SLIDESHOW CORRENTE (SE IN ESECUZIONE, PER SICUREZZA)
      this.stopSlideshow();
      
      // FACCIO PARTIRE LO SLIDESHOW NUOVO
      this.TimerId = window.setInterval(instanceName + ".goToPrevPage();", this.SlideshowInterval);
   }
}

// #                                                     #
// #                     NAVIGAZIONE                     #
// #                                                     #
// #######################################################